@@ -213,11 +213,22 @@ class OrbitalBuilder(Builder):
                     for best in sorted_entries:
                         task = best["task_id"]
 
-                        task_doc = TaskDocument(
-                            **self.tasks.query_one({"task_id": int(task),
-                                                    "formula_alphabetical": formula,
-                                                    "orig": {"$exists": True}})
-                        )
+                        tdoc = self.tasks.query_one({"task_id": task,
+                                                     "formula_alphabetical": formula,
+                                                     "orig": {"$exists": True}})
+
+                        if tdoc is None:
+                            try:
+                                tdoc = self.tasks.query_one({"task_id": int(task),
+                                                             "formula_alphabetical": formula,
+                                                             "orig": {"$exists": True}})
+                            except ValueError:
+                                tdoc = None
+
+                        if tdoc is None:
+                            continue
+
+                        task_doc = TaskDocument(**tdoc)
 
                         if task_doc is None:
                             continue
@@ -258,7 +269,7 @@ class OrbitalBuilder(Builder):
             self.orbitals.remove_docs({self.orbitals.key: {"$in": molecule_ids}})
             self.orbitals.update(
                 docs=docs,
-                key=["molecule_id"],
+                key=["molecule_id", "solvent"],
             )
         else:
             self.logger.info("No items to update")
